@@ -108,8 +108,18 @@ class MainWindow(QtGui.QMainWindow):
 	MainWindow.labelbdemuenabled.setGeometry(QtCore.QRect(510, 395, 391, 20))
 	MainWindow.labelbdemuenabled.setObjectName("label")
 	MainWindow.labelbdemuenabled.setText(QtGui.QApplication.translate("MainWindow", "BD Emulation enabled", None, QtGui.QApplication.UnicodeUTF8))
+	MainWindow.labelbdDEVemuenabled = QtGui.QLabel(self)
+	MainWindow.labelbdDEVemuenabled.setGeometry(QtCore.QRect(510, 395, 391, 20))
+	MainWindow.labelbdDEVemuenabled.setObjectName("label")
+	MainWindow.labelbdDEVemuenabled.setText(QtGui.QApplication.translate("MainWindow", "Dev BD Emulation enabled", None, QtGui.QApplication.UnicodeUTF8))
+	MainWindow.labelbdDEVemudisabled = QtGui.QLabel(self)
+	MainWindow.labelbdDEVemudisabled.setGeometry(QtCore.QRect(510, 395, 391, 20))
+	MainWindow.labelbdDEVemudisabled.setObjectName("label")
+	MainWindow.labelbdDEVemudisabled.setText(QtGui.QApplication.translate("MainWindow", "Dev BD Emulation disabled", None, QtGui.QApplication.UnicodeUTF8))
 	MainWindow.labelbdemudisabled.hide()
 	MainWindow.labelbdemuenabled.hide()
+	MainWindow.labelbdDEVemudisabled.hide()
+	MainWindow.labelbdDEVemuenabled.hide()
 	# Buttons
         self.button1 = QtGui.QPushButton("Jailbreak mode on", self)
         self.button1.setObjectName("button1")
@@ -126,11 +136,13 @@ class MainWindow(QtGui.QMainWindow):
 	MainWindow.button4.setGeometry(QtCore.QRect(290, 300, 247, 50))
 	MainWindow.button4.hide()
 	self.checkmodulestatus()
-#	self.payload_list = QtGui.QComboBox(self)
-#	self.payload_list.setGeometry(QtCore.QRect(300, 320, 190, 45))
-#	self.payload_list.addItem("payload_bdemu.bin")
-#	self.payload_list.addItem("payload_no_bdemu.bin")
-
+	MainWindow.payload_list = QtGui.QComboBox(self)
+	MainWindow.payload_list.setGeometry(QtCore.QRect(290, 300, 247, 50))
+	MainWindow.payload_list.addItem("No BD Emulation", -1)
+	MainWindow.payload_list.addItem("BD Emulation", -1)
+	MainWindow.payload_list.addItem("No BD Dev Emulation", -1)
+	MainWindow.payload_list.addItem("BD Dev Emulation ", -1)
+	MainWindow.payload_list.hide()
         self.layout = QtGui.QVBoxLayout()
         self.setLayout(self.layout)
 
@@ -143,13 +155,27 @@ class MainWindow(QtGui.QMainWindow):
 	QtCore.QObject.connect(self.aboutQtAction, QtCore.SIGNAL("triggered()"), self.aboutQt)
 	QtCore.QObject.connect(self.showLogs, QtCore.SIGNAL("triggered()"), self.logs)
 	QtCore.QObject.connect(self.help, QtCore.SIGNAL("triggered()"), self.helpafterrun)
+	QtCore.QObject.connect(MainWindow.payload_list, QtCore.SIGNAL("activated(int)"), self.selectPayload)
 #      QtCore.QObject.connect(self.portrait, QtCore.SIGNAL("triggered()"), self.portraitmode)
 
+
+    def selectPayload(self, i):
+	if i == 0:
+		self.disablebdemu()
+	elif i == 1:
+		self.enablebdemu()
+	elif i == 2:
+		self.disabledevbdemu()
+	elif i == 3:
+		self.enabledevbdemu()
+
     def enablebdemu(self):
-	MainWindow.button3.hide()
-	MainWindow.button4.show()
+#	MainWindow.button3.hide()
+#	MainWindow.button4.show()
 	os.popen("/opt/psfreedom/resources/scripts/helperscript.sh --enablebdemu")
 	MainWindow.labelbdemudisabled.hide()
+	MainWindow.labelbdDEVemudisabled.hide()
+	MainWindow.labelbdDEVemuenabled.hide()
 	MainWindow.labelbdemuenabled.show()
 	bus = dbus.SystemBus()
         iface = dbus.Interface(bus.get_object('org.freedesktop.Notifications',
@@ -157,11 +183,27 @@ class MainWindow(QtGui.QMainWindow):
                                               'org.freedesktop.Notifications')
         iface.SystemNoteInfoprint("BD Emulation enabled.")
 
+    def enabledevbdemu(self):
+#	MainWindow.button3.hide()
+#	MainWindow.button4.show()
+	os.popen("/opt/psfreedom/resources/scripts/helperscript.sh --enabledevbdemu")
+	MainWindow.labelbdemudisabled.hide()
+	MainWindow.labelbdemuenabled.hide()
+	MainWindow.labelbdDEVemudisabled.hide()
+	MainWindow.labelbdDEVemuenabled.show()
+	bus = dbus.SystemBus()
+        iface = dbus.Interface(bus.get_object('org.freedesktop.Notifications',
+                                              '/org/freedesktop/Notifications'),
+                                              'org.freedesktop.Notifications')
+        iface.SystemNoteInfoprint("Dev BD Emulation enabled.")
+
     def disablebdemu(self):
-	MainWindow.button3.show()
-	MainWindow.button4.hide()
+#	MainWindow.button3.show()
+#	MainWindow.button4.hide()
 	os.popen("/opt/psfreedom/resources/scripts/helperscript.sh --disablebdemu")
 	MainWindow.labelbdemuenabled.hide()
+	MainWindow.labelbdDEVemudisabled.hide()
+	MainWindow.labelbdDEVemuenabled.hide()
 	MainWindow.labelbdemudisabled.show()
 	bus = dbus.SystemBus()
         iface = dbus.Interface(bus.get_object('org.freedesktop.Notifications',
@@ -169,6 +211,20 @@ class MainWindow(QtGui.QMainWindow):
                                               'org.freedesktop.Notifications')
         iface.SystemNoteInfoprint("BD Emulation disabled.")
 
+    def disabledevbdemu(self):
+#	MainWindow.button3.show()
+#	MainWindow.button4.hide()
+	os.popen("/opt/psfreedom/resources/scripts/helperscript.sh --disabledevbdemu")
+	MainWindow.labelbdemudisabled.hide()
+	MainWindow.labelbdemuenabled.hide()
+	MainWindow.labelbdDEVemuenabled.hide()
+	MainWindow.labelbdDEVemudisabled.show()
+	bus = dbus.SystemBus()
+        iface = dbus.Interface(bus.get_object('org.freedesktop.Notifications',
+                                              '/org/freedesktop/Notifications'),
+                                              'org.freedesktop.Notifications')
+        iface.SystemNoteInfoprint("Dev BD Emulation disabled.")
+
 
     def checkmodulestatus(self):
 	if os.path.isfile("/proc/psfreedom/status"):
@@ -180,13 +236,9 @@ class MainWindow(QtGui.QMainWindow):
 		payload = os.popen("cat /proc/psfreedom/payload | grep dev").read()
 		payloadstripped = str(payload).strip()
 		if str(payloadstripped) == "/dev_bdvd":
-			MainWindow.button4.show()
-			MainWindow.button3.hide()
 			MainWindow.labelbdemudisabled.hide()
 			MainWindow.labelbdemuenabled.show()
 		else:
-			MainWindow.button4.hide()
-			MainWindow.button3.show()
 			MainWindow.labelbdemuenabled.hide()
 			MainWindow.labelbdemudisabled.show()
 	else:
@@ -440,7 +492,8 @@ class MainWindow(QtGui.QMainWindow):
                                               '/org/freedesktop/Notifications'),
                                               'org.freedesktop.Notifications')
         iface.SystemNoteInfoprint("Jailbreak mode enabled")
-	MainWindow.button3.show()
+#	MainWindow.button3.show()
+	MainWindow.payload_list.show()
 	MainWindow.labelenabled.setGeometry(QtCore.QRect(510, 365, 391, 20))
 	MainWindow.labelbdemudisabled.show()
 	self.firstrun()
@@ -458,10 +511,11 @@ class MainWindow(QtGui.QMainWindow):
                                               '/org/freedesktop/Notifications'),
                                               'org.freedesktop.Notifications')
         iface.SystemNoteInfoprint("Jailbreak mode disabled")
-	MainWindow.button3.hide()
-	MainWindow.button4.hide()
+#	MainWindow.button3.hide()
+#	MainWindow.button4.hide()
 	MainWindow.labelbdemudisabled.hide()
 	MainWindow.labelbdemuenabled.hide()
+	MainWindow.payload_list.hide()
 
 
 # Starting up the app
