@@ -2,6 +2,7 @@
 
 # Status file
 STATUS=/proc/psfreedom/status
+BINDIR=/lib/firmware
 
 if [ ! -f $STATUS ];
 	then
@@ -31,14 +32,28 @@ enablebdemu()
 {
 	become_root $*
 
-	cat /lib/firmware/payload_bdemu.bin > /proc/psfreedom/payload
+	cat $BINDIR/payload_bdemu.bin > /proc/psfreedom/payload
+}
+
+enabledevbdemu()
+{
+	become_root $*
+
+	cat $BINDIR/payload_dev_dbemu.bin > /proc/psfreedom/payload
 }
 
 disablebdemu()
 {
 	become_root $*
 
-	cat /lib/firmware/payload_no_bdemu.bin > /proc/psfreedom/payload
+	cat $BINDIR/payload_no_bdemu.bin > /proc/psfreedom/payload
+}
+
+disabledevbdemu()
+{
+	become_root $*
+
+	cat $BINDIR/payload_dev_nodbemu.bin > /proc/psfreedom/payload
 }
 
 status()
@@ -63,7 +78,7 @@ help ()
 {
 	echo "PSFreedom helper script, use to change payload"
 	echo 	
-	echo "Usage: --enaablebdemu | --disablebdemu | --status | --help"
+	echo "Usage: --enaablebdemu | --enaabledevbdemu | --disablebdemu | --disabledevbdemu | --status | --help"
 
 	exit 1
 }
@@ -79,6 +94,14 @@ case "$argv0" in
 		disablebdemu $*
 		;;
 
+	-E|--enaabledevbdemu|enaabledevbdemu)
+		enaabledevbdemu $*
+		;;
+
+	-D|--disabledevbdemu|disabledevbdemu)
+		disabledevbdemu $*
+		;;
+
 	-s|--status|status)
 		status $*
 		;;
